@@ -1,7 +1,7 @@
 package Array::Diff;
-$Array::Diff::VERSION = '0.07_01'; # TRIAL
+$Array::Diff::VERSION = '0.07_02'; # TRIAL
 
-$Array::Diff::VERSION = '0.0701';use strict;
+$Array::Diff::VERSION = '0.0702';use strict;
 use warnings;
 use base qw/Class::Accessor::Fast/;
 
@@ -111,7 +111,22 @@ the C<added> and C<deleted> properties.
 
 =head1 SEE ALSO
 
-L<Algorithm::Diff>
+L<Algorithm::Diff> - the underlying implementation of the diff algorithm.
+If you've got L<Algorithm::Diff::XS> installed, that will be used.
+
+L<YAML::Diff> - find difference between two YAML documents.
+
+L<HTML::Differences> - find difference between two HTML documents.
+This uses a more sane approach than L<HTML::Diff>.
+
+L<XML::Diff> - find difference between two XML documents.
+
+L<Hash::Diff> - find the differences between two Perl hashes.
+
+L<Data::Diff> - find difference between two arbitrary data structures.
+
+L<Text::Diff> - can find difference between two inputs, which can be
+data structures or file names.
 
 =head1 AUTHOR
 
